mod font;
mod panel;
mod ext;
mod tray;
mod util;
mod x11;

use chan;
use chan_signal;
use config::Config;

use std::thread;

pub const SIZE: u16 = 20;

pub fn ui_main(signal: chan::Receiver<chan_signal::Signal>, cfg: &Config) -> i32 {
    if let Some(conn) = x11::Connection::new() {
        let (tx, rx) = chan::sync(0);
        {
            let conn = conn.clone_connection();
            thread::spawn(move || {
                loop {
                    match conn.wait_for_event() {
                        Some(event) => { tx.send(event); },
                        None => { break; }
                    }
                }
            });
        }

        let panel = panel::Panel::new(conn, cfg);
        panel.create();

        loop {
            chan_select!(
                rx.recv() -> event => {
                    if panel.handle_event(event.unwrap()) {
                        println!("Exiting");
                        break;
                    }
                },
                signal.recv() => {
                    panel.finish();
                }
            );
        }
    }
    0
}
